@@ -31,6 +31,7 @@ from pyiron_base.database.jobtable import (
 )
 from pyiron_base.settings.logger import set_logging_level
 from pyiron_base.generic.hdfio import ProjectHDFio
+from pyiron_base.generic.filedata import load_file
 from pyiron_base.job.jobtype import JobType, JobTypeChoice, JobFactory
 from pyiron_base.server.queuestatus import (
     queue_delete_job,
@@ -1448,8 +1449,7 @@ class Project(ProjectPath):
             return ProjectHDFio(project=self, file_name=file_name)
         if item in self.list_files():
             file_name = posixpath.join(self.path, "{}".format(item))
-            with open(file_name) as f:
-                return f.readlines()
+            return load_file(file_name)
         if item in self.list_dirs():
             with self.open(item) as new_item:
                 return new_item.copy()
